@@ -1,6 +1,12 @@
-/*
- * Copyright (C) 2001 Hideki Ikemoto <ikemo@wakaba.jp>
- */
+/***************************************************************************
+ *   Copyright (C) 2003 by Hideki Ikemoto                                  *
+ *   ikemo@users.sourceforge.jp                                            *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ ***************************************************************************/
 
 #ifndef _KITA_H_
 #define _KITA_H_
@@ -12,15 +18,16 @@
 #include <kapplication.h>
 #include <kdockwidget.h>
 
-#include "kitaview.h"
 #include "kitaconfig.h"
 
+#include "libkita/thread.h"
+
 class KPrinter;
 class KToggleAction;
 class KURL;
-class KitaThreadView;
+class KitaThreadTabWidget;
 class KitaBoardView;
-class KitaSubjectView;
+class KitaSubjectTabWidget;
 class KLineEdit;
 
 namespace KParts{
@@ -36,19 +43,19 @@ namespace KParts{
  * @version $APP_VERSION
  */
 
-class Kita : public KDockMainWindow
+class KitaMainWindow : public KDockMainWindow
 {
     Q_OBJECT
 public:
     /**
      * Default Constructor
      */
-    Kita();
+    KitaMainWindow();
 
     /**
      * Default Destructor
      */
-    virtual ~Kita();
+    virtual ~KitaMainWindow();
 
     /**
      * Use this method to load whatever file/URL you have
@@ -90,31 +97,44 @@ private slots:
     void optionsConfigureToolbars();
     void optionsPreferences();
     void newToolbarConfig();
+    void windowShowBoardlist();
+    void windowShowSubjectlist();
+    void windowMenuAboutToShow();
+    void slotEditCopy();
 
     void changeStatusbar(const QString& text);
     void changeCaption(const QString& text);
     void slotOpenURLRequest(const KURL& url, const KParts::URLArgs&);
-    void slotSetVestedNum(const KURL& threadURL, int resCount);
-    void slotFontChanged(QFont& font);
+    void updateThreadCache( const Kita::Thread& thread );
+    void setFont( const QFont& font );
     void slotWriteSucceeded();
     void slotUrlLine();
     void setUrl(const KURL& url);
+    void bookmark( const Kita::Thread& thread, bool on );
+    void slotThread( const Kita::Thread& thread );
 
 private:
-    KitaThreadView *m_threadView;
+    KitaThreadTabWidget* m_threadView;
     KitaBoardView* m_boardView;
-    KitaSubjectView* m_subjectView;
+    KitaSubjectTabWidget* m_subjectView;
     KLineEdit* m_urlLine;
 
     KPrinter   *m_printer;
     KToggleAction *m_toolbarAction;
     KToggleAction *m_statusbarAction;
+    KToggleAction *m_boardListAction;
+    KToggleAction* m_subjectListAction;
+
+    KDockWidget* m_boardDock;
+    KDockWidget* m_subjectDock;
 
     void setupAccel();
     void setupActions();
     void setupView();
     void loadCache();
     void saveCache();
+    void loadFavorites();
+    void saveFavorites();
 };
 
 #endif // _KITA_H_
