@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2003 by Hideki Ikemoto                                  *
- *   ikemo@wakaba.jp                                                       *
+ *   ikemo@users.sourceforge.jp                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,26 +15,42 @@
 
 #include "kitaboardviewbase.h"
 
-class Kita;
 class KURL;
 
+namespace Kita
+{
+  class Board;
+  class Category;
+}
+
 /**
- * 
- * Hideki Ikemoto
+ *
+ * @author Hideki Ikemoto <ikemo@users.sourceforge.jp>
  **/
 class KitaBoardView : public KitaBoardViewBase
 {
   Q_OBJECT
 
+  QString getCategory(const QString& line) const;
+  Kita::Board getBoard(const QString& line) const;
+  bool isBoardUrl(const KURL& url) const;
+  QPtrList<Kita::Category> getCategoryList(const QString& html) const;
+  void printCateogryList(QPtrList<Kita::Category>& list);
+
+private slots:
+  void loadBoard(QListViewItem* item);
+  void slotContextMenuRequested( QListViewItem*, const QPoint&, int );
+
 public:
   KitaBoardView(QWidget *parent, const char *name=0);
   ~KitaBoardView();
+
 public slots:
   void loadBoardList();
-  void slotLoadBoard(QListViewItem* item);
-  void slotFontChanged(QFont& font);
+  void setFont( const QFont& font );
+
 signals:
-  void signalLoadBoard(const KURL& url, const QString& boardName);
+  void clicked( const Kita::Board& board );
 };
 
 #endif
