@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2003 by Hideki Ikemoto                                  *
- *   ikemo@wakaba.jp                                                       *
+ *   ikemo@users.sourceforge.jp                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -14,6 +14,7 @@
 #include <qtextcodec.h>
 #include <qregexp.h>
 #include <qfile.h>
+#include <qclipboard.h>
 
 // kdelibs/kio
 #include <kio/slaveconfig.h>
@@ -24,20 +25,25 @@
 #include <klistview.h>
 #include <kiconloader.h>
 #include <klocale.h>
- 
+#include <kpopupmenu.h>
+#include <krun.h>
+
 #include "kitasubjectview.h"
+#include "favoritelistview.h"
 #include "kita.h"
 #include "kitacacheinfo.h"
 #include "part/kita2ch.h"
+#include "libkita/thread.h"
 
 enum SubjectViewRows {
   Row_ID,
   Row_Icon,
   Row_Subject,
   Row_ResNum,
-  Row_Vested,
+  Row_Read,
   Row_Unread,
-  Row_DatName
+  Row_DatName,
+  Row_DatURL
 };
 
 KitaSubjectView::KitaSubjectView(QWidget *parent, const char *name)
@@ -47,23 +53,25 @@ KitaSubjectView::KitaSubjectView(QWidget *parent, const char *name)
     SearchButton->setPixmap( SmallIcon("find") );
     HideButton->setPixmap( SmallIcon("filter") );
   }
-  
+
   subjectList->addColumn(i18n("No."));
   subjectList->addColumn("");
   subjectList->addColumn(i18n("Title"));
   subjectList->addColumn(i18n("ResNum"));
-  subjectList->addColumn(i18n("Vested"));
+  subjectList->addColumn(i18n("ReadNum"));
   subjectList->addColumn(i18n("Unread"));
   subjectList->addColumn(i18n("Dat"));
 
   subjectList->setColumnWidth(Row_Subject, 400);
   subjectList->setColumnWidthMode(Row_Subject, QListView::Manual);
 
-  connect(subjectList, SIGNAL(clicked(QListViewItem*)), SLOT(loadThread(QListViewItem*)));
   connect( SearchButton, SIGNAL( clicked() ), SLOT( slotSearchButton() ) );
   connect( SearchCombo, SIGNAL( activated(int) ), SLOT( slotSearchButton() ) );
-  connect(this, SIGNAL(signalSubjectListClicked(QListViewItem*)), subjectList, SIGNAL(clicked(QListViewItem*)));
   connect( HideButton, SIGNAL( toggled(bool) ), SLOT( slotHideButton(bool) ) );
+  connect( subjectList, SIGNAL( contextMenuRequested( QListViewItem*, const QPoint&, int ) ),
+                        SLOT( slotContextMenuRequested( QListViewItem*, const QPoint&, int ) ) );
+  connect( subjectList, SIGNAL( mouseButtonClicked( int, QListViewItem*, const QPoint&, int ) ),
+                        SLOT( loadThread( int, QListViewItem* ) ) );
 }
 
 KitaSubjectView::~KitaSubjectView()
@@ -74,15 +82,22 @@ void KitaSubjectView::reloadSubject()
 {
 }
 
-void KitaSubjectView::loadThread(QListViewItem* item)
+void KitaSubjectView::loadThread( int, QListViewItem* item )
 {
+  if( ! item ) return;
+
   QString datName = item->text(Row_DatName);
   KURL datURL = m_board.url();
   datURL.addPath("/dat/" + datName);
-  emit signalShowThread(m_board, Kita2ch::Thread(datURL));
+
+  Kita::Thread* thread = new Kita::Thread( m_board, datURL,
+                                           item->text( Row_Subject ),
+                                           item->text( Row_Read ).toInt() );
+
+  emit signalShowThread( *thread );
 }
 
-void KitaSubjectView::slotLoadBoard(const KURL& url, const QString& boardName)
+void KitaSubjectView::loadBoard(const Kita::Board& board)
 {
   // reset member variables.
   {
@@ -91,27 +106,28 @@ void KitaSubjectView::slotLoadBoard(const KURL& url, const QString& boardName)
     m_prevquery = "";
   }
 
-  m_board = Kita2ch::Board(url, boardName);
-  m_board.refreshChildList();
+  m_board = board;
 
   KitaCacheInfo* cache = KitaCacheInfo::getInstance();
-  QPtrList<Kita2ch::Thread> threadList = m_board.getThreadList();
+  QPtrList<Kita::Thread> threadList = m_board.getThreadList();
 
   // clear list
   subjectList->clear();
 
   for(unsigned i=0; i<threadList.count(); i++) {
-    Kita2ch::Thread* thread = threadList.at(i);
+    Kita::Thread* thread = threadList.at(i);
 
-    int vested = cache->getVestedNum(thread->datURL());
-    new KListViewItem(subjectList,
-                      QString("%1").arg(i+1, 4),
-                      "",
-                      thread->name(),
-                      QString("%1").arg(thread->resNum(), 4),
-                      vested > 0 ? QString::number(vested) : "",
-                      vested > 0 && thread->resNum() != vested ? QString::number(thread->resNum() - vested) : "",
-                      thread->datURL().fileName());
+    int readNum = cache->readNum( thread->datURL() );
+    int resNum = thread->resNum();
+    new KListViewItem( subjectList,
+                       QString("%1").arg(i+1, 4),
+                       "",
+                       thread->name(),
+                       QString("%1").arg( resNum, 4 ),
+                       (readNum > 0) ? QString::number(readNum) : QString(""),
+                       (readNum > 0 && resNum != readNum) ? QString::number( resNum - readNum ) : QString(""),
+                       thread->datURL().fileName(),
+                       thread->datURL().prettyURL() );
   }
 
   if( HideButton->isOn() ) {
@@ -210,7 +226,55 @@ void KitaSubjectView::slotHideButton(bool on)
   }
 }
 
-void KitaSubjectView::slotFontChanged(QFont& font)
+void KitaSubjectView::setFont( const QFont& font )
 {
   subjectList->setFont(font);
 }
+
+void KitaSubjectView::updateThread(const Kita::Thread& updated_thread)
+{
+  for(QListViewItem* item = subjectList->firstChild(); item; item = item->nextSibling() ) {
+    if( item->text(Row_DatURL) == updated_thread.datURL().prettyURL() ) {
+      int resNum = item->text( Row_ResNum ).toInt();
+      int readNum = updated_thread.resNum();
+      item->setText( Row_Read, QString::number( readNum ) );
+      item->setText( Row_Unread, readNum > 0 && resNum != readNum ? QString::number(resNum - readNum) : QString(""));
+    }
+  }
+}
+
+void KitaSubjectView::slotContextMenuRequested( QListViewItem* item, const QPoint& point, int )
+{
+  if( item == 0 ) {
+    return;
+  }
+
+  KPopupMenu popup( 0 );
+  popup.insertItem( i18n("Open with Web Browser"), 0 );
+  popup.insertItem( i18n("Open with new tab"), 1 );
+  popup.insertItem( i18n("Copy title and URL"), 2 );
+
+  QString datName = item->text(Row_DatName);
+  KURL datURL = m_board.url();
+  datURL.addPath("/dat/" + datName);
+
+  Kita::Thread thread( m_board, datURL );
+  thread.setName( item->text( Row_Subject ) );
+  thread.setResNum( item->text( Row_Read ).toInt() );
+
+  QClipboard* clipboard = QApplication::clipboard();
+
+  switch( popup.exec( point ) ) {
+  case 0:
+    KRun::runURL( thread.url(), "text/html" );
+    break;
+  case 1:
+    emit signalShowThreadWithNewTab( thread );
+    break;
+  case 2:
+    clipboard->setText( thread.name() + "\n" + thread.url().url() );
+    break;
+  default:
+    break;
+  }
+}
