@@ -1,6 +1,6 @@
-/**************************************************************************
+/***************************************************************************
  *   Copyright (C) 2003 by Hideki Ikemoto                                  *
- *   ikemo@wakaba.jp                                                       *
+ *   ikemo@users.sourceforge.jp                                            *
  *   linux 󥫥פ餰ο                                        *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -9,41 +9,39 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#include <qtextstream.h>
-#include <qlayout.h>
-#include <qtoolbutton.h>
-#include "qcp932codec.h"
-#include <qsjiscodec.h>
-#include <qlabel.h>
-#include <qcombobox.h>
-#include <qprogressdialog.h>
-
-#include <time.h>
+#include "kitathreadview.h"
 
 #include <kurl.h>
-#include <kio/slaveconfig.h>
-#include <kio/jobclasses.h>
-#include <kio/scheduler.h>
-
 #include <khtmlview.h>
-#include <dom/html_element.h>
-#include <dom/html_inline.h>
-#include <dom/html_base.h>
-
-#include <kglobal.h>
-#include <kconfig.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kaction.h>
 #include <kmessagebox.h>
 
+#include <dom/html_inline.h>
+#include <dom/html_base.h>
+#include <dom/html_list.h>
+
+#include <qlayout.h>
+#include <qtoolbutton.h>
+#include <qlabel.h>
+#include <qcombobox.h>
+#include <qprogressdialog.h>
+#include <qcursor.h>
+#include <qtextbrowser.h>
+#include <qmessagebox.h>
+#include <qdatetime.h>
+
 #include "kitahtmlpart.h"
-#include "kitathreadview.h"
 #include "kitawritedialog.h"
 #include "../kitacacheinfo.h"
 #include "kita2ch.h"
 
-#include <qmessagebox.h>
+#include "libkita/comment.h"
+#include "libkita/qcp932codec.h"
+#include "libkita/favoritethreads.h"
+
+#define MAX_LABEL_LENGTH 60
 
 static const char* cookie_title = "񤭹߳ǧ";
 static const char* cookie_message =
@@ -53,32 +51,27 @@ static const char* cookie_message =
 "\n"
 "Ǥ餦Ȥƽ񤭹ߤޤ\n";
 
+static const char* kokomade_yonda = "<p style=\"background-color: #CCCCCC; text-align: center\">"
+"ޤɤ"
+"</p>";
+
 KitaThreadView::KitaThreadView(QWidget *parent, const char *name)
     : KitaThreadViewBase(parent, name)
     , m_parent( parent )
-    , m_currentJob( 0 )
-    , m_labelMaxLength( 60 )
+    , m_popup( 0 )
+    , m_access( 0 )
 {
   m_threadPart = new KitaHTMLPart(threadFrame);
   QHBoxLayout* aLayout = new QHBoxLayout(threadFrame);
   aLayout->addWidget(m_threadPart->view());
 
-  {
-    m_threadPart->setStandardFont("Gothic [Mona]");
-    m_threadPart->setZoomFactor(120); // 12px;
-#if 0 // provides you with mona font info.
-    QString info;
-    info +=  view()->font().family();
-    info +="\n";
-    info +=  QString("size: %1pt %2px\n").arg( view()->font().pointSizeFloat() ).arg( view()->font().pixelSize() );
-    QMessageBox::information( 0, "", info );
-#endif
-  }
-
+  m_threadPart->setZoomFactor(120); // XXX
   {
     SearchButton->setPixmap( SmallIcon("find") );
     HighLightButton->setPixmap( SmallIcon("idea") );
     ReloadButton->setPixmap( SmallIcon("reload") );
+    GobackAnchorButton->setPixmap( SmallIcon("2leftarrow") );
+    BookmarkButton->setPixmap( SmallIcon("bookmark_add") );
   }
 
   setAcceptDrops( true ); // DND Drop eneble: 2nd stage. - enable on "KitaThreadView" widget and disable on the others(child widgets of "KitaThreadView").
@@ -93,16 +86,16 @@ KitaThreadView::KitaThreadView(QWidget *parent, const char *name)
   connect( m_threadPart, SIGNAL( onURL(const QString&) ), SLOT( slotOnURL(const QString&) ) );
   connect( m_threadPart, SIGNAL( setLocationBarURL(const QString &) ),
   			 SIGNAL( setLocationBarURL(const QString &) ) );
+  connect( BookmarkButton, SIGNAL( toggled(bool) ), SLOT( slotBookmarkButtonClicked(bool) ) );
   connect( SearchButton, SIGNAL( clicked() ), SLOT( slotSearchButton() ) );
   connect( SearchCombo, SIGNAL( activated(int) ), SLOT( slotSearchButton() ) );
   connect( HighLightButton, SIGNAL( toggled(bool) ), SLOT( slotHighLightenButton(bool) ) );
-  connect( GobackAnchorButton, SIGNAL( clicked() ), SLOT( gobackAnchor() ) );
+  connect( GobackAnchorButton, SIGNAL( clicked() ), m_threadPart, SLOT( gobackAnchor() ) );
   connect( ReloadButton, SIGNAL( clicked() ), SLOT( slotReloadButton() ) );
 
   KParts::BrowserExtension * ext = m_threadPart->browserExtension();
   connect( ext, SIGNAL( openURLRequest(const KURL&, const KParts::URLArgs&) ),
                  SLOT( slotOpenURLRequest(const KURL&, const KParts::URLArgs&) ) );
-      		//SIGNAL( openURLRequest(const KURL&, const KParts::URLArgs&) ) );
   connect( ext, SIGNAL( createNewWindow (const KURL&, const KParts::URLArgs&) ),
       		SIGNAL( createNewWindow (const KURL&, const KParts::URLArgs&) ) );
   connect( ext, SIGNAL( setLocationBarURL(const QString &) ),
@@ -117,11 +110,16 @@ KitaThreadView::KitaThreadView(QWidget *parent, const char *name)
 
 KitaThreadView::~KitaThreadView() {}
 
-QString KitaThreadView::threadSubject() const
+const QString KitaThreadView::threadName() const
 {
   return m_thread.name();
 }
 
+const KURL KitaThreadView::threadURL() const
+{
+  return m_thread.url();
+}
+
 void KitaThreadView::slotDOMNodeActivated(const DOM::Node &node)
 {
   { //process Anchor tags. Anchor tags not proccessed here cause 'emit KParts::BrowserExtention::openURLRequest()'
@@ -129,56 +127,27 @@ void KitaThreadView::slotDOMNodeActivated(const DOM::Node &node)
 
     if ( ! anchor.href().isEmpty() )
     {
-      printf("  AnchorNodeActivated:: \n" );
+      qDebug("  AnchorNodeActivated:: \n" );
     } // end: anchor.href().isEmpty()
   } // end of Anchor tags.
 }
 
-void KitaThreadView::slotShowThread(const Kita2ch::Board& board, const Kita2ch::Thread& thread)
+void KitaThreadView::showThread( const Kita::Thread& thread )
 {
   { //reset member variables associated with a thread.
-    m_threadPart->setPrevQuery("");
-    m_threadPart->resetHit();
-    m_threadPart->resetHitCount();
-    m_writeResult = "";
-    m_threadData = "";
-    m_threadPart->setContents("");
-    m_threadPart->clearPosition();
+    m_threadPart->reset();
   }
 
-  m_board = board;
   m_thread = thread;
-  if ( m_thread.datURL().protocol() != "k2ch" ) {
-    KIO::SlaveConfig::self()->setConfigData("http", m_thread.datURL().host() ,
-                                          "UserAgent", "Monazilla/1.00 (Kita/0.4)");
-  }
 
-  KIO::TransferJob* job = KIO::get(m_thread.datURL(), true, true);
-  m_currentJob = job;
-
-  connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
-          SLOT(slotReceiveThreadData(KIO::Job*, const QByteArray&)));
-  connect(job, SIGNAL(result(KIO::Job*)), SLOT(slotThreadResult(KIO::Job*)));
-  connect(job, SIGNAL(redirection(KIO::Job *, const KURL&) ), SLOT(slotRedirection(KIO::Job *, const KURL&) ) );
-
-  // use 'HTTP-Headers' metadata.
-  job->addMetaData("PropagateHttpHeader", "true");
+  m_access = new Kita::ThreadAccess( thread );
+  connect( m_access, SIGNAL( redirection( const QString& ) ), SIGNAL( setLocationBarURL( const QString& ) ) );
+  QString result = m_access->get();
+  m_serverTime = getServerTimeFromHttpHeaders( m_access->getHeader() );
+  update( result );
 }
 
-void KitaThreadView::slotRedirection(KIO::Job *, const KURL & newURL)
-{
-  printf("  Redirected to newURL: %s\n", newURL.url().latin1() );
-  m_thread = Kita2ch::Thread(newURL);
-  emit setLocationBarURL(newURL.url());
-}
-
-void KitaThreadView::slotReceiveThreadData(KIO::Job*, const QByteArray& data)
-{
-  QCString cstr(data.data(), data.size()+1);
-  m_threadData.append(cstr);
-}
-
-int KitaThreadView::getServerTimeFromHttpHeaders(QString headers)
+int KitaThreadView::getServerTimeFromHttpHeaders( const QString& headers )
 {
   // parse HTTP headers
   QStringList headerList = QStringList::split("\n", headers);
@@ -186,7 +155,7 @@ int KitaThreadView::getServerTimeFromHttpHeaders(QString headers)
   QString dateStr = headerList.grep(regexp)[0];
   if(regexp.search(dateStr) == -1) {
     // invalid date format
-    return time(NULL);
+    return QDateTime::currentDateTime().toTime_t();
   } else {
     // I hate this format ;p
     QString usLocalDateStr = regexp.cap(1) + " " + regexp.cap(3) + " " +
@@ -207,31 +176,21 @@ void KitaThreadView::setSubjectLabel(const QString& boardName, const QString& th
     disp = QString("[%1] %2").arg(boardName).arg(threadName);
   }
 
-  disp.truncate( m_labelMaxLength );
+  disp.truncate( MAX_LABEL_LENGTH );
   subjectLabel->setText( disp );
 }
 
-void KitaThreadView::slotThreadResult(KIO::Job* job)
+void KitaThreadView::update( const QString& result )
 {
-  m_currentJob = 0;
-  if(job->error()) {
-    job->showErrorDialog();
-    return;
-  }
-
-  QCp932Codec codec;
-  QTextStream stream(m_threadData, IO_ReadOnly);
-  stream.setCodec(&codec);
-  QString line;
+  QStringList lines = QStringList::split( "\n", result );
   QString text;
   int num = 0;
 
-  m_serverTime = getServerTimeFromHttpHeaders(job->queryMetaData("HTTP-Headers"));
-
-  int total = m_threadData.length();
+  int total = result.length();
   int step = 0;
   int divide = total / ( 100 / 5 );
   int next = divide;
+  int prevResNum = m_thread.resNum();
   QProgressDialog * progress = new QProgressDialog( m_parent );
   progress->setTotalSteps( static_cast<int>(total * 0.7) );
   progress->setLabelText( "Parse DAT file.....");
@@ -239,10 +198,10 @@ void KitaThreadView::slotThreadResult(KIO::Job* job)
 
   text += "<html><head>";
   text += "</head><body>";
-  while(!stream.atEnd()) {
 
-    line = stream.readLine();
-    Kita2ch::Comment comment(line);
+  for( QStringList::iterator it = lines.begin(); it != lines.end(); ++it ) {
+    QString line = (*it);
+    Kita::Comment comment(line);
     if( comment.isValid() == false) {
       continue;
     }
@@ -253,6 +212,10 @@ void KitaThreadView::slotThreadResult(KIO::Job* job)
     }
     text += comment.toHtml(num);
 
+    if( prevResNum == num ) {
+      text += QString::fromLocal8Bit( kokomade_yonda );
+    }
+
     if( (step+=line.length()) > next ) {
       progress->setProgress( step );
       next += divide;
@@ -261,72 +224,67 @@ void KitaThreadView::slotThreadResult(KIO::Job* job)
   delete progress;
 
   m_thread.setResNum(num);
-  emit setVestedNum(m_thread.datURL(), m_thread.resNum());
+  emit thread( m_thread );
 
-#if 0
-  QString disp( m_thread.name() );
-  if ( ! m_board.name().isEmpty() ) { disp.prepend( QString("[%1]").arg(m_board.name()) ); }
-  disp.truncate( m_labelMaxLength );
-  subjectLabel->setText( disp );
-#else
-  setSubjectLabel( m_board.name(), m_thread.name() );
-#endif
+  setSubjectLabel( m_thread.boardName(), m_thread.name() );
 
-  {
-    int target;
-    for ( target = 1; target < m_thread.resNum(); target += 100 )
-      text += QString(" <a href=\"#%1\">%3</a> ").arg(target).arg(target);
-    text += "<br/>";
-  }
-#if 0
-  text += QString("<a href=\"%1#%2\">check new one.</a>").arg( m_datURL.url() ).arg( m_rescount );
-#endif
+  text += footer( prevResNum );
   text += "</body></html>";
-  m_threadPart->setContents(text);
 
-  slotDisplayContents( m_threadPart->contents(), m_thread.datURL() );
-  if ( HighLightButton->isOn() ) {
-    HighLightButton->toggle();
-  }
-  m_threadData.truncate(0);
-
-  if ( m_thread.datURL().hasRef() ) {
-    if ( ! gotoAnchor( m_thread.datURL().encodedHtmlRef()) )
-      gotoAnchor( m_thread.datURL().htmlRef() );
-  } else {
-    gotoAnchor( QString().setNum(m_thread.resNum() - 1) );
-  }
-  m_threadPart->clearPosition();
-  m_threadPart->pushCurrentPosition();
+  m_threadPart->displayContentsAndGotoURL( text, m_thread );
+  updateButton();
 
   emit showThreadCompleted( m_thread.url() );
 }
 
-void KitaThreadView::slotShowErrorDialog(const QString& input, const KURL&)
+void KitaThreadView::updateButton()
+{
+  writeButton->setEnabled( true );
+  BookmarkButton->setEnabled( true );
+  ReloadButton->setEnabled( true );
+
+  if ( HighLightButton->isOn() ) {
+    HighLightButton->toggle();
+  }
+  if( FavoriteThreads::getInstance()->contains( m_thread.datURL().prettyURL() ) ) {
+    BookmarkButton->setOn( true );
+  } else {
+    BookmarkButton->setOn( false );
+  }
+}
+
+const QString KitaThreadView::footer( int prevResNum ) const
+{
+  QString text;
+  int target;
+  for ( target = 1; target < m_thread.resNum(); target += 100 ) {
+    text += QString(" <a href=\"#%1\">%3</a> ").arg(target).arg(target);
+  }
+  text += QString(" <a href=\"#%1\">New</a> ").arg( prevResNum + 1 );
+  text += "<br/>";
+
+  return text;
+}
+
+void KitaThreadView::slotShowErrorDialog( const QString& input, const KURL& )
 {
   qDebug("#%s#", (const char *)input.local8Bit());
-  Kita2ch::WriteResult writeResult(input);
+  Kita::WriteResult writeResult(input);
 
   qDebug("code = %d", writeResult.code());
   switch( writeResult.code() ) {
-  case Kita2ch::K2ch_Unknown:
+  case Kita::K2ch_Unknown:
     // probably OK.
     emit writeSucceeded();
     slotReloadButton();
     break;
-  case Kita2ch::K2ch_True:
+  case Kita::K2ch_True:
+  case Kita::K2ch_False:
+  case Kita::K2ch_Error:
+  case Kita::K2ch_Check:
     KMessageBox::error(0, writeResult.message(), writeResult.title());
     break;
-  case Kita2ch::K2ch_False:
-    KMessageBox::error(0, writeResult.message(), writeResult.title());
-    break;
-  case Kita2ch::K2ch_Error:
-    KMessageBox::error(0, writeResult.message(), writeResult.title());
-    break;
-  case Kita2ch::K2ch_Check:
-    KMessageBox::error(0, writeResult.message(), writeResult.title());
-    break;
-  case Kita2ch::K2ch_Cookie:
+  case Kita::K2ch_Cookie:
     if( KMessageBox::questionYesNo(0, QString::fromLocal8Bit(cookie_message),
                                       QString::fromLocal8Bit(cookie_title)) == KMessageBox::Yes) {
       KitaWriteDialog* dialog = openDialog( m_postInfo );
@@ -341,37 +299,27 @@ void KitaThreadView::slotShowErrorDialog(const QString& input, const KURL&)
   }
 }
 
-void KitaThreadView::slotDisplayContents(const QString& input, const KURL& url)
+KitaWriteDialog* KitaThreadView::openDialog( const Kita::PostInfo& info )
 {
-  m_threadPart->slotDisplayContents(input, url);
-}
-
-KitaWriteDialog* KitaThreadView::openDialog(Kita2ch::PostInfo& info)
-{
-  KitaWriteDialog* new_dialog = KitaWriteDialog::open( info );
-  connect( new_dialog, SIGNAL( postStarted( KIO::Job *, const Kita2ch::PostInfo& ) ),
-           this, SLOT( slotPostStarted( KIO::Job*, const Kita2ch::PostInfo&) ) );
+  KitaWriteDialog* new_dialog = KitaWriteDialog::open( info, m_thread.boardName(), m_thread.name() );
+  connect( new_dialog, SIGNAL( postStarted( KIO::Job *, const Kita::PostInfo& ) ),
+           this, SLOT( slotPostStarted( KIO::Job*, const Kita::PostInfo&) ) );
   connect( new_dialog, SIGNAL( postResponse(const QString&, const KURL&) ),
       	   this, SLOT( slotShowErrorDialog(const QString&, const KURL&) ) );
-#if 0 // !!postRenponce!!
-  connect( new_dialog, SIGNAL( postResponse(const QString&, const KURL&) ),
-      	   this, SLOT( slotDisplayContents(const QString&, const KURL&) ) );
-#else
   connect( new_dialog, SIGNAL( postResponse(const QString&, const KURL&) ),
       	   this, SIGNAL( postResponse(const QString&, const KURL&) ) );
-#endif
   return new_dialog;
 }
 
 void KitaThreadView::slotWriteButtonClicked()
 {
-  QSjisCodec cp932Codec;
-  KURL bbscgiURL = KURL(m_board.url(), "../test/bbs.cgi");
+//  QSjisCodec cp932Codec;
+  KURL bbscgiURL = KURL( m_thread.boardUrl(), "../test/bbs.cgi");
   bbscgiURL.setProtocol( "http" );
 
-  Kita2ch::PostInfo info;
+  Kita::PostInfo info;
   info.host = bbscgiURL.host();
-  info.bbs = m_board.id();
+  info.bbs = m_thread.boardId();
   info.key = m_thread.datID();
   info.time = QString("%1").arg(m_serverTime);
 
@@ -379,10 +327,6 @@ void KitaThreadView::slotWriteButtonClicked()
   dialog->show(); // work asynchronus.
 }
 
-void KitaThreadView::slotCanceled(KIO::Job*)
-{
-}
-
 void KitaThreadView::slotSearchButton()
 {
   insertSearchCombo();
@@ -394,24 +338,21 @@ void KitaThreadView::slotHighLightenButton(bool yes)
 {
   insertSearchCombo();
   QStringList list = parseSearchQuery( SearchCombo->currentText() );
-  highLighten( yes, list );
+  m_threadPart->highLighten( yes, list );
 }
 
 void KitaThreadView::insertSearchCombo()
 {
-  int count;
-  bool found = false;
-
-  for( count = 0; count < SearchCombo->count(); ++count ) {
-    if ( SearchCombo->text( count ) ==  SearchCombo->currentText() ) {
-      found = true;
-      break;
+  for( int count = 0; count < SearchCombo->count(); ++count ) {
+    if ( SearchCombo->text( count ) == SearchCombo->currentText() ) {
+      // found
+      return;
     }
   }
-  if ( ! found ) SearchCombo->insertItem( SearchCombo->currentText() );
+  SearchCombo->insertItem( SearchCombo->currentText() );
 }
 
-QStringList KitaThreadView::parseSearchQuery(const QString &input)
+QStringList KitaThreadView::parseSearchQuery(const QString &input) const
 {
   QStringList tmp = QStringList::split( ' ', input );
   QStringList ret_list;
@@ -432,78 +373,88 @@ void KitaThreadView::searchNext(const QStringList &query)
     return;
   }
   if ( query != m_threadPart->prevQuery() ) {
-    highLighten( true, query );
+    m_threadPart->highLighten( true, query );
     m_threadPart->resetHit(); //A next jump-search target reset to '0'.
     return;
   }
 
-  gotoAnchor( QString("highlighten%1").arg( m_threadPart->nextHit() )  );
-}
-
-void KitaThreadView::highLighten(bool yes, const QStringList &query)
-{
-  if ( ! yes ) {
-    m_threadPart->setUserStyleSheet( QString("") );
-    return;
-  }
-
-  // Use style sheet to highlighten.
-  QString highlightCSS( ".highlight { color: %1; background: %2; } ");
-#if 0
-  QColorGroup cg = m_threadPart->view()->colorGroup();
-  highlightCSS = highlightCSS.arg( cg.highlightedText().name() ).arg( cg.highlight().name()  );
-#else
-  highlightCSS = highlightCSS.arg( "yellow" ).arg( "black" );
-#endif
-//  m_threadPart->setUserStyleSheet( highlightCSS );
-
-  if ( m_threadPart->prevQuery() != query && !query.isEmpty() ) {
-    m_threadPart->setPrevQuery(query);
-    slotDisplayContents( m_threadPart->contents(), m_thread.datURL() );
-    DOM::NodeList nodes;
-    m_threadPart->resetHit();
-    nodes = m_threadPart->document().getElementsByTagName("body");
-    m_threadPart->highLightenNodes( nodes, query );
-  }
-  m_threadPart->setUserStyleSheet( highlightCSS );
+  m_threadPart->gotoAnchor( QString("highlighten%1").arg( m_threadPart->nextHit() )  );
 }
 
 void KitaThreadView::slotOnURL(const QString& url)
 {
   emit signalChangeStatusbar(url);
+
+  // TODO: enterEvent()ơäƤȤtipɽ뤳ȡ
+  if ( ! url.isEmpty() ) {
+    KHTMLView* view = m_threadPart->view();
+
+    if( m_popup ) {
+      delete m_popup;
+    }
+
+    m_popup = new QFrame( view, "res_popup", WStyle_Customize | WStyle_NoBorder | WStyle_Tool | WType_TopLevel );
+    m_browser = new QTextBrowser( m_popup );
+    m_browser->zoomOut( static_cast<int>( m_browser->pointSize() * 0.3 ) );
+    m_browser->setPaletteBackgroundColor( "yellow" );
+    m_browser->setWordWrap( QTextEdit::NoWrap );
+    m_browser->setResizePolicy( QScrollView::AutoOne );
+    connect( m_threadPart->view(), SIGNAL( leave() ), SLOT( hidePopup() ) );
+
+    int refNum = 0;
+    if ( url.at(0) == '#' ) {
+      refNum = url.mid(1).toInt();
+    } else {
+      KURL filteredURL = filterReadCGI( KURL( m_thread.datURL(), url ) );
+      refNum = filteredURL.ref().toInt();
+    }
+
+    if( refNum != 0 ) {
+      DOM::NodeList comments = m_threadPart->htmlDocument().body().getElementsByTagName( "dl" );
+      DOM::HTMLDListElement comment_dl = static_cast<DOM::HTMLDListElement>(comments.item( refNum - 1 ));
+      QString innerHTML = comment_dl.innerHTML().string();
+
+      m_browser->setText( innerHTML );
+      m_browser->resize( m_browser->contentsWidth() + 10, m_browser->contentsHeight() );
+      m_popup->adjustSize();
+
+      QPoint pos = QCursor::pos();
+      pos -= QPoint( 0, m_popup->height() ) + QPoint( -10, 10 );
+      m_popup->move( pos );
+
+      m_popup->show();
+    }
+  } else {
+    m_popup->hide();
+  }
 }
 
-bool KitaThreadView::gotoAnchor( const QString &name )
+void KitaThreadView::hidePopup()
 {
-  return m_threadPart->gotoAnchor( name );
-}
-
-bool KitaThreadView::gobackAnchor()
-{
-  return m_threadPart->gobackAnchor();
+  if( m_popup ) {
+    m_popup->hide();
+  }
 }
 
 void KitaThreadView::slotPopupMenu( KXMLGUIClient *client, const QPoint &global, const KURL &url, const QString &mimeType, mode_t mode)
 {
   KActionCollection * collection = client->actionCollection();
   KAction * action;
-  action = new KAction( i18n("goback anchor"), SmallIcon("idea"), KShortcut(), this, SLOT( gobackAnchor() ), collection, "goback_anchor" );
-  printf("  KitaThreadView::slotPopupMenu() %p\n", action);
+  action = new KAction( i18n("goback anchor"), SmallIcon("idea"), KShortcut(), m_threadPart, SLOT( gobackAnchor() ), collection, "goback_anchor" );
   emit popupMenu(client, global, url, mimeType, mode);
 }
 
 void KitaThreadView::slotOpenURLRequest(const KURL& url, const KParts::URLArgs& args)
 {
-  printf(" openURLRequest:: orgURL %s\n", url.url().latin1() );
   if ( url.url().at(0) == '#' ) {
-    gotoAnchor( url.ref() );
+    m_threadPart->gotoAnchor( url.ref() );
     return;
   }
   KURL datURL = filterReadCGI( url );
   if ( datURL.host() == m_thread.datURL().host()
     && datURL.path() == m_thread.datURL().path() )
   {
-    if ( datURL.hasRef() ) gotoAnchor( datURL.ref() );
+    if ( datURL.hasRef() ) m_threadPart->gotoAnchor( datURL.ref() );
     return;
   }
   emit openURLRequest(datURL, args);
@@ -511,7 +462,7 @@ void KitaThreadView::slotOpenURLRequest(const KURL& url, const KParts::URLArgs&
 
 void KitaThreadView::slotReloadButton()
 {
-  slotShowThread(m_board, m_thread);
+  showThread( m_thread );
 }
 
 KURL KitaThreadView::filterReadCGI(const KURL& url)
@@ -520,13 +471,11 @@ KURL KitaThreadView::filterReadCGI(const KURL& url)
   if ( url.path().contains("/test/read.cgi") ) {
     newURL.setProtocol( m_thread.datURL().protocol() );
     QString tmp = url.path().section("/test/read.cgi", 1);
-    //printf("    tmp: %s\n", tmp.latin1() );
 
     QString newPath = QString( "/%1/dat/%2.dat" )
                .arg( tmp.section('/', 1, 1) )
 	       .arg( tmp.section('/', 2, 2) );
     newURL.setPath( newPath );
-    //printf("    newPath: %s\n", newPath.latin1() );
 
     QString refBase = tmp.section('/', 3);
     if ( ! refBase.isEmpty() ) {
@@ -536,18 +485,35 @@ KURL KitaThreadView::filterReadCGI(const KURL& url)
       else newURL.setRef( refBase );
     }
   }
-  printf("    newURL: %s\n", newURL.url().latin1() );
+  qDebug("    newURL: %s\n", newURL.url().latin1() );
   return newURL;
 }
 
-void KitaThreadView::slotFontChanged(QFont& font)
+void KitaThreadView::setFont( const QFont& font )
 {
   m_threadPart->setStandardFont(font.family());
   subjectLabel->setFont(font);
 }
-// vim:sw=2:
 
-void KitaThreadView::slotPostStarted( KIO::Job*, const Kita2ch::PostInfo& info)
+void KitaThreadView::slotPostStarted( KIO::Job*, const Kita::PostInfo& info)
 {
   m_postInfo = info;
 }
+
+void KitaThreadView::slotBookmarkButtonClicked( bool on )
+{
+  emit bookmarked( m_thread, on );
+}
+
+void KitaThreadView::killJob()
+{
+  if( m_access ) {
+    m_access->killJob();
+  }
+}
+
+KParts::BrowserExtension* KitaThreadView::browserExtension()
+{
+  return m_threadPart->browserExtension();
+}
+// vim:sw=2:
