@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2003 by Hideki Ikemoto                                  *
- *   ikemo@wakaba.jp                                                       *
+ *   ikemo@users.sourceforge.jp                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -9,9 +9,12 @@
  ***************************************************************************/
 
 #include "kitawritedialog.h"
-#include "qcp932codec.h"
+#include "libkita/qcp932codec.h"
 #include "kitaconfig.h"
 
+#include <ksqueezedtextlabel.h>
+#include <klocale.h>
+
 #include <qlineedit.h>
 #include <qtextedit.h>
 #include <qpushbutton.h>
@@ -24,10 +27,7 @@ KitaWriteDialogPrivate * KitaWriteDialog::s_private = 0;
 KitaWriteDialog::KitaWriteDialog(QWidget *parent, const char *name)
   : KitaWriteDialogBase(parent, name)
 {
-  //QFont font = font();
   QFont font = KitaConfig::font();
-//  font.setFamily("Gothic [Mona]");
-//  font.setPixelSize( 12 );
   bodyText->setFont( font );
   nameLine->setFont( font );
   nameLabel->setFont( font );
@@ -39,29 +39,29 @@ KitaWriteDialog::~KitaWriteDialog()
 {
 }
 
-QString KitaWriteDialog::name()
+const QString KitaWriteDialog::name() const
 {
   return nameLine->text();
 }
 
-QString KitaWriteDialog::mail()
+const QString KitaWriteDialog::mail() const
 {
   return mailLine->text();
 }
 
-QString KitaWriteDialog::body()
+const QString KitaWriteDialog::body() const
 {
   return bodyText->text();
 }
 
-void KitaWriteDialog::fetchPostInfo( Kita2ch::PostInfo * storage )
+void KitaWriteDialog::fetchPostInfo( Kita::PostInfo * storage ) const
 {
   storage->name = name();
   storage->mail = mail();
   storage->body = body();
 }
 
-KitaWriteDialog *  KitaWriteDialog::open( const Kita2ch::PostInfo& info )
+KitaWriteDialog* KitaWriteDialog::open( const Kita::PostInfo& info, const QString& boardName, const QString& threadName )
 {
   if ( ! info.check() ) return 0;
   if ( ! s_private ) {
@@ -82,6 +82,10 @@ KitaWriteDialog *  KitaWriteDialog::open( const Kita2ch::PostInfo& info )
   new_dlg->mailLine->setText(info.mail);
   new_dlg->bodyText->setText(info.body);
 
+  new_dlg->boardNameLabel->setText( boardName );
+  new_dlg->threadNameLabel->setText( threadName );
+
+  new_dlg->setCaption( i18n("Write in %1").arg( threadName ) );
   return new_dlg;
 }
 
@@ -99,7 +103,7 @@ void KitaWriteDialog::postMessage()
   //int mib = QTextCodec::codecForName("CP932")->mibEnum();
   QString postStr = m_postInfo.postStr();
 
-  printf("query: %s\n", postStr.latin1());
+  qDebug("query: %s\n", postStr.latin1());
   m_array.resize(0);
 
   KIO::TransferJob * job = KIO::http_post(bbscgi, postStr.utf8(), true);
@@ -126,7 +130,7 @@ void  KitaWriteDialog::slotPostFinished(KIO::Job *job)
 {
   QString response = QTextCodec::codecForName("sjis")->toUnicode( m_array );
   QCString output = QTextCodec::codecForName("eucJP")->fromUnicode( response );
-  printf("response:\n%s\n", output.data() );
+  qDebug("response:\n%s\n", output.data() );
   emit postFinished( job );
   KURL bbscgi;
   bbscgi.setProtocol( "http" );
