@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2003 by Hideki Ikemoto                                  *
- *   ikemo@wakaba.jp                                                       *
+ *   ikemo@users.sourceforge.jp                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -30,27 +30,27 @@ class KitaWriteDialog : public KitaWriteDialogBase
 public:
   KitaWriteDialog(QWidget *parent=0, const char *name=0 );
   virtual ~KitaWriteDialog();
-  QString name();
-  QString mail();
-  QString body();
+  const QString name() const;
+  const QString mail() const;
+  const QString body() const;
 
   virtual bool error(){ return false; };
 
-  static KitaWriteDialog * open( const Kita2ch::PostInfo& info );
+  static KitaWriteDialog * open( const Kita::PostInfo& info, const QString&, const QString& );
 
 public slots:
   void postMessage();
 
 signals:
-  void postStarted( KIO::Job *, const Kita2ch::PostInfo& );
+  void postStarted( KIO::Job *, const Kita::PostInfo& );
   void postFinished( KIO::Job * );
   void postResponse( const QString& response, const KURL& bbscgi = KURL() );
 
 protected:
-  Kita2ch::PostInfo m_postInfo;
+  Kita::PostInfo m_postInfo;
 
 private:
-  void fetchPostInfo( Kita2ch::PostInfo * storage );
+  void fetchPostInfo( Kita::PostInfo * storage ) const;
 
   QCString m_array;
   bool m_error;
