@@ -1,6 +1,12 @@
-/*
- * Copyright (C) 2001 Hideki Ikemoto <ikemo@wakaba.jp>
- */
+/***************************************************************************
+ *   Copyright (C) 2003 by Hideki Ikemoto                                  *
+ *   ikemo@users.sourceforge.jp                                            *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ ***************************************************************************/
 
 #include "pref.h"
 
@@ -28,10 +34,11 @@ KitaPreferences::KitaPreferences()
 //    frame = addPage(i18n("Second Page"), i18n("Page Two Options"));
 //    m_pageTwo = new KitaPrefPageTwo(frame);
 
-    connect(m_fontPage, SIGNAL(signalFontChanged(QFont&)), SIGNAL(signalFontChanged(QFont&)));
+    connect( m_fontPage, SIGNAL( fontChanged( const QFont& ) ),
+                         SIGNAL( fontChanged( const QFont& ) ) );
 }
 
-KitaFontPrefPage::KitaFontPrefPage(QWidget *parent)
+KitaFontPrefPage::KitaFontPrefPage( QWidget *parent )
     : KitaFontPrefBase(parent)
 {
   fontButton->setText(KitaConfig::font().family());
@@ -46,11 +53,11 @@ void KitaFontPrefPage::slotFontButtonClicked()
   if( KFontDialog::getFont(font, false, this) == QDialog::Accepted ) {
     fontButton->setText(font.family());
     fontButton->setFont(font);
-    emit signalFontChanged(font);
+    emit fontChanged(font);
   }
 }
 
-KitaPrefPageTwo::KitaPrefPageTwo(QWidget *parent)
+KitaPrefPageTwo::KitaPrefPageTwo( QWidget *parent )
     : QFrame(parent)
 {
     QHBoxLayout *layout = new QHBoxLayout(this);
